Time Bomb Client
---
[![pypi](https://img.shields.io/pypi/v/timebomb-client.svg)](https://pypi.python.org/pypi/timebomb-client)
[![versions](https://img.shields.io/pypi/pyversions/timebomb-client.svg)](https://github.com/thmslmr/timebomb-client)

**UNDER DEVELOPMENT**

Just enough to connect a [timebomb-server](https://github.com/thmslmr/timebomb-server) and play Time Bomb in your terminal.

Installation
---
```bash
$ pip install timebomb-client --user
```

Run
---
```bash
$ timebomb HOST.ADDRESS
```
